@echo off


echo Script file for generating XML Schema documentation
echo using xs3p schema documentation generator.

echo Usage: schemaDocumentation.bat -xsdPath=path\To\XSD\File -imageFolder=path\To\Images\Folder -mainOutputDir=main\Output\Dir -htmlFileName=fileName.html -diagramExtension=.jpg -useHashCodes=true -generateChunks=false -hideComments=true -hideAnnotations=true -cssURL=file://path/To/CSS
echo ----------------------------------------------------------------------------------------------
echo Parameters:
echo -xsdPath  - The path to XML Schema file
echo -imageFolder  - The path to the folder where generated images will be saved into. Relative 
echo                     to the mainOutputDir
echo -mainOutputDir - The path to the html output directory. This contains the HTML files and the images directory.
echo -htmlFileName - The name of the HTML file relative to mainOutputDir.
echo -diagramExtension - Optional (defaults to .png). Either ".png" or ".jpg" to specify the diagrams type
echo -useHashCodes - Optional (defaults to true). If enabled then the anchors and links will be generated using the hashcode of the component
echo      identifier instead of using the identifier itself. This is useful when the schema component
echo      names contain characters that are not directly supported by the browsers or by the file system.
echo      Possible values are true/false. 
echo -generateChunks - Optional (defaults to false). For large schemas you can use 'Generate chunks' option
echo      Possible values are true/false. 
echo -hideComments - Optional (defaults to true). Hides/Shows comments present in the generated diagram images.
echo      Possible values are true/false. 
echo -hideAnnotations - Optional (defaults to true). Hides/Shows annotations present in the generated diagram images.
echo      Possible values are true/false. 
echo -cssURL - Optional. The URL of the stylesheet to be used by the generated HTML files. Must be specified in URL syntax.
echo Example: schemaDocumentation.bat -xsdPath=samples\personal.xsd -imageFolder=schemaDiagrams -mainOutputDir=samples -htmlFileName=personal.xsd.html -diagramExtension=.png -useHashCodes=true -generateChunks=false -cssURL=personal.css -hideComments=true -hideAnnotations=true
echo ----------------------------------------------------------------------------------------------

rem Default values for optional parameters.
SET BASE_DIR=%~dp0
SET GENERATE_CHUNKS=false
SET USE_HASH_CODES=true
SET HIDE_COMMENTS=true
SET HIDE_ANNOTATIONS=true
SET DIAGRAMS_EXTENSION=.png

rem Slurp the command line arguments. This loop allows for an unlimited number
rem of arguments (up to the command line limit, anyway).
echo.
echo Current command line parameters:
:setupArgs
if ""%1""=="""" goto doneStart

rem detect args
echo %1 = %2
  if %1 == -xsdPath (set XSD_PATH=%2)
  if %1 == -imageFolder (set IMAGES_FOLDER=%2)
  if %1 == -mainOutputDir (set MAIN_OUTPUT_DIR=%2)
  if %1 == -htmlFileName (set HTML_FILE_NAME=%2)
  if %1 == -diagramExtension (set DIAGRAMS_EXTENSION=%2)
  if %1 == -useHashCodes (set USE_HASH_CODES=%2)
  if %1 == -generateChunks (set GENERATE_CHUNKS=%2)
  if %1 == -hideComments (set HIDE_COMMENTS=%2)
  if %1 == -hideAnnotations (set HIDE_ANNOTATIONS=%2)
  if %1 == -cssURL (set CSS_URL=%2)

shift
shift
goto setupArgs
rem This label provides a place for the argument list loop to break out
rem and for NT handling to skip to.

:doneStart
echo.

if not ""%XSD_PATH%""=="""" if not ""%IMAGES_FOLDER%""=="""" if not ""%MAIN_OUTPUT_DIR%""=="""" if not ""%HTML_FILE_NAME%""=="""" goto execute

SET ERRORS=The following parameters are not specified:
if ""%XSD_PATH%""=="""" SET ERRORS=%ERRORS%  pathToXSDFile
if ""%IMAGES_FOLDER%""=="""" SET ERRORS=%ERRORS%   imageFolder
if ""%MAIN_OUTPUT_DIR%""=="""" SET ERRORS=%ERRORS%   mainOutputDir
if ""%HTML_FILE_NAME%""=="""" SET ERRORS=%ERRORS%   htmlFileName

SET ERRORS=%ERRORS%  Correct command line arguments and try again.

echo %ERRORS%

goto end

:execute
rem BASE_DIR is expanded pathname of the current script under NT

rem generates diagrams

echo Running transformation

java -cp "%BASE_DIR%;%BASE_DIR%/classes;%BASE_DIR%/lib/oxygen.jar;%BASE_DIR%/lib/xml-apis.jar;%BASE_DIR%/lib/xercesImpl.jar;%BASE_DIR%/lib/log4j.jar;%BASE_DIR%/lib/resolver.jar" ro.sync.exml.SwingSDImageGenerator -xsdPath %XSD_PATH% -imageFolder %MAIN_OUTPUT_DIR%\\%IMAGES_FOLDER% -diagramExtension %DIAGRAMS_EXTENSION% -useHashCodes %USE_HASH_CODES% -generateChunks %GENERATE_CHUNKS% -hideComments %HIDE_COMMENTS% -hideAnnotations %HIDE_ANNOTATIONS% -htmlFileName %HTML_FILE_NAME%


rem generate the documentation file


SET PARAMS= showDiagrams=true
SET PARAMS=%PARAMS% imagesBaseURL=%IMAGES_FOLDER%
SET PARAMS=%PARAMS% sortByComponent=true
SET PARAMS=%PARAMS% useJavaScript=true
SET PARAMS=%PARAMS% printAllSuperTypes=true
SET PARAMS=%PARAMS% printAllSubTypes=true
SET PARAMS=%PARAMS% printLegend=true
SET PARAMS=%PARAMS% printGlossary=true
SET PARAMS=%PARAMS% printNSPrefixes=true
SET PARAMS=%PARAMS% mainSchemaOutputFile=%HTML_FILE_NAME%
SET PARAMS=%PARAMS% showLogicalDiagrams=true
SET PARAMS=%PARAMS% mainDocBase=%MAIN_OUTPUT_DIR%
SET PARAMS=%PARAMS% mainDocFile=%HTML_FILE_NAME%
SET PARAMS=%PARAMS% diagramImagesExtension=%DIAGRAMS_EXTENSION%
SET PARAMS=%PARAMS% generateChunks=%GENERATE_CHUNKS%
SET PARAMS=%PARAMS% useHashcodes=%USE_HASH_CODES%

if not ""%CSS_URL%""=="""" SET PARAMS=%PARAMS% externalCSSURL=%CSS_URL%

echo.
echo Starting stylesheet processor
java -cp "%BASE_DIR%/lib/saxon8.jar;" net.sf.saxon.Transform -o %MAIN_OUTPUT_DIR%\\%HTML_FILE_NAME% %XSD_PATH% "%BASE_DIR%/frameworks/xs3p/xs3p.xsl" %PARAMS%
echo Finished

:end